/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DownloadZipFileCommand.as 20693 2011-01-10 08:30:50Z skabore $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.autostart.command {
    import com.adobe.cairngorm.commands.ICommand;
    import com.adobe.cairngorm.control.CairngormEvent;
    import com.adobe.cairngorm.control.CairngormEventDispatcher;

    import mx.rpc.IResponder;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;
    import mx.collections.ArrayCollection;

    import org.ow2.jasmine.kerneos.common.event.ServerSideExceptionEvent;
    import org.ow2.jasmine.kerneos.common.view.ServerSideException;
    import org.ow2.jonas.admin.autostart.business.*;
    import org.ow2.jonas.admin.autostart.event.*;
    import org.ow2.jonas.admin.autostart.model.*;
    import org.ow2.jonas.admin.autostart.vo.*;

    /**
      * The command class from the cairngorm model.
      */
    [Event(name="serverSideException", type="org.ow2.jasmine.kerneos.common.event.ServerSideExceptionEvent")]
    public class DownloadZipFileCommand implements ICommand, IResponder {
        /**
         * Retrieve the delegate and use it to make the call.
         */
        public function execute(event:CairngormEvent):void {
            ////////////////////////////////////////////////
            //                                            //
            //             Handle the execution           //
            //                                            //
            ////////////////////////////////////////////////

            var delegate:IBuilderDelegate = BuilderModelLocator.getInstance().getBuilderDelegate();
            delegate.responder = this;
            var model:BuilderModelLocator = BuilderModelLocator.getInstance();
            delegate.downloadFile(model.builderVO.parameter);
        }

        /**
         * Handle the result of the server call.
         */
        public function result(data:Object):void {
            ////////////////////////////////////////////////
            //                                            //
            //             Handle the result              //
            //                                            //
            ////////////////////////////////////////////////

            var modelLoc:BuilderModelLocator = BuilderModelLocator.getInstance();
            modelLoc.jonasZipFile = (data as ResultEvent).result as String;
        }

        /**
         * Raise an alert when something is wrong.
         */
        public function fault(info:Object):void {

            ////////////////////////////////////////
            //                                    //
            //             Handle fault           //
            //                                    //
            ////////////////////////////////////////
            // Retrieve the fault event
            var faultEvent : FaultEvent = FaultEvent(info);

            // Tell the view and let it handle this
            var serverSideExceptionEvent : ServerSideExceptionEvent =
                new ServerSideExceptionEvent(
                    "serverSideException",
                    new ServerSideException("Error while Executing the action",
                                            "The operation could not be performed."
                                            + "\n" + faultEvent.fault.faultCode
                                            + "\n" + faultEvent.fault.faultString,
                                            faultEvent.fault.getStackTrace()));

            // Dispatch the event using the cairngorm event dispatcher
            CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);
        }
    }
}
